function [ hndDataSet ] = FormatDimensions( hndDataSet, varargin )
%FORMATDIMENSIONS Changes the dimensions of a dataset to more readable
%dimensions
%
% Keep in mind that most DataSet functions will now longer work as intended
% after calling FormatDimensions
%
%   varargin:
%       'rad' to force radians
%       'deg' to force degree
%       'round' followed by the number of digits after the dot
%       'autoround' automatically choose a sensible number of digits for
%       each dimension

nRound = [];
bAutoRound = 0;
for k = 1:length(varargin)
    if ischar(varargin{k})
        switch lower(varargin{k})
            case 'rad'
                hndDataSet = hndDataSet.Convert2rad;
            case 'deg'
                hndDataSet = hndDataSet.Convert2deg; 
            case 'round'
                nRound = varargin{k+1};
            case 'autoround'
                bAutoRound = 1;
        end
    end
end


clDims = hndDataSet.GetDimensions;

for nDim = 1:size(clDims,1)
    if strcmpi(clDims{nDim,3},'date')
        continue;
    elseif strcmpi(clDims{nDim,3},'unknown')
        continue;
    end
    % fix the units
    values = clDims{nDim,2};
    meanval = mean(abs(values));
    pot = (log10(meanval)-1)/3;
    pot = round(pot);
    %Find first higher order
    %pot = ceil(pot);
    
    values = values / 10^(pot*3);
    
    prefix = '';
    switch(pot)
        case -4
            prefix = 'p';
        case -3
            prefix = 'n';
        case -2
            prefix = 'u';
        case -1
            prefix='m';
        case 1
            prefix='k';
        case 2
            prefix='M';
        case 3
            prefix='G';
        case 4
            prefix='T';
    end
    if(strcmpi(prefix,''))
        values = clDims{nDim,2};
    end
    
    if ~isempty(nRound)
        values = round(values*10^(nRound))/10^(nRound);
    end
    
    if bAutoRound
        dSmallestdiff = min(abs(diff(values)));    
        pot = floor(log10(dSmallestdiff));
        precision = 0;
        if(pot<0) %=> smallest diff smaller than 1
            precision = -pot;
        end
        precision = precision+2;
        values = round(values*10^(precision))/10^(precision);
    end
    
    unit = [prefix char(clDims{nDim,3})];
    
    clDims{nDim,2} = values;
    clDims{nDim,3} = unit;  
end
hndDataSet = hndDataSet.SetDimensions(clDims);

end

